@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007   Alex Shulgin
+ * Copyright (C) 2007,2008   Alex Shulgin
  *
- * This file is part of png++ the C++ wrapper for libpng.  Png++ is free
+ * This file is part of png++ the C++ wrapper for libpng.  PNG++ is free
  * software; the exact copying conditions are as follows:
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,7 @@
 #include <iostream>
 #include <istream>
 
-#include <endian.h>
-
+#include "config.hpp"
 #include "error.hpp"
 #include "streaming_base.hpp"
 #include "reader.hpp"
@@ -90,7 +89,7 @@ namespace png
      * any calls to \c get_next_row().  The value of \c 0 is passed
      * for the \c pass number.
      *
-     * An optional template parameter \c info_holder encapsulated
+     * An optional template parameter \c info_holder encapsulates
      * image_info storage policy.  Using def_image_info_holder results
      * in image_info object stored as a sub-object of the consumer
      * class.  You may specify image_info_ref_holder in order to use a
@@ -168,8 +167,7 @@ namespace png
 #ifdef PNG_READ_SWAP_SUPPORTED
                 rd.set_swap();
 #else
-                throw error("Cannot read 16-bit image --"
-                            " recompile with PNG_READ_SWAP_SUPPORTED.");
+                throw error("Cannot read 16-bit image: recompile with PNG_READ_SWAP_SUPPORTED.");
 #endif
             }
 #endif
@@ -181,8 +179,7 @@ namespace png
 #ifdef PNG_READ_INTERLACING_SUPPORTED
                 pass_count = rd.set_interlace_handling();
 #else
-                throw error("Cannot read interlaced image --"
-                            " interlace handling disabled.");
+                throw error("Cannot read interlaced image: interlace handling disabled.");
 #endif
             }
             else
