@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007   Alex Shulgin
+ * Copyright (C) 2007,2008   Alex Shulgin
  *
- * This file is part of png++ the C++ wrapper for libpng.  Png++ is free
+ * This file is part of png++ the C++ wrapper for libpng.  PNG++ is free
  * software; the exact copying conditions are as follows:
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,7 @@
 
 #include <png.h>
 
+#include "config.hpp"
 #include "types.hpp"
 #include "error.hpp"
 #include "color.hpp"
@@ -53,6 +54,7 @@
 #include "generator.hpp"
 #include "consumer.hpp"
 #include "pixel_buffer.hpp"
+#include "solid_pixel_buffer.hpp"
 #include "require_color_space.hpp"
 #include "convert_color_space.hpp"
 #include "image.hpp"
@@ -63,10 +65,10 @@
  * \section sec_intro Introduction
  *
  * This is the documentation for png++ the C++ wrapper for libpng.
- * This page documents png++ version 0.2.1.
+ * This page documents png++ version 0.2.
  *
- * Png++ aims to provide simple yet powerful C++ interface to libpng,
- * the PNG reference implementation library.  Png++ is free software
+ * PNG++ aims to provide simple yet powerful C++ interface to libpng,
+ * the PNG reference implementation library.  PNG++ is free software
  * distributed under a modified variant of BSD <a
  * href="http://www.nongnu.org/pngpp/license.html">license</a>.
  *
@@ -108,7 +110,7 @@
  *
  * \section sec_installing Installing
  *
- * Png++ comes as a set of header files and does not require
+ * PNG++ comes as a set of header files and does not require
  * compilation to be installed.  For the same reason there are no
  * binary packages for png++.
  *
@@ -261,10 +263,10 @@
  *
  * Also, you can check out sources directly from SVN repository:
  * svn://svn.sv.nongnu.org/pngpp/trunk/ or
- * http://svn.sv.nongnu.org/pngpp/trunk/ (for people w/o outgoing svn).
+ * http://svn.sv.nongnu.org/svn/pngpp/trunk/ (for people w/o outgoing svn).
  *
  * Online version of this documentation can be found here:
- * http://www.nongnu.org/pngpp/doc/html/index.html
+ * http://www.nongnu.org/pngpp/doc/@VERSION@/index.html
  *
  * \section sec_bugs Bugs
  *
